@@ -19,7 +19,7 @@
 #include <gstreamermm/event.h>
 #include <gstreamermm/filter.h>
 #include <gstreamermm/format.h>
-//TODO: #include <gstreamermm/ghostpad.h> (when bug #539108 is fixed)
+#include <gstreamermm/ghostpad.h>
 #include <gstreamermm/index.h>
 #include <gstreamermm/indexfactory.h>
 #include <gstreamermm/interface.h>
@@ -32,6 +32,7 @@
 #include <gstreamermm/pipeline.h>
 #include <gstreamermm/plugin.h>
 #include <gstreamermm/pluginfeature.h>
+#include <gstreamermm/preset.h>
 #include <gstreamermm/query.h>
 #include <gstreamermm/segment.h>
 #include <gstreamermm/structure.h>
@@ -43,10 +44,32 @@
 #include <gstreamermm/value.h>
 #include <gstreamermm/xml.h>
 
-// Library base includes
+// Core library base includes
 #include <gstreamermm/basesrc.h>
 #include <gstreamermm/basesink.h>
 #include <gstreamermm/basetransform.h>
 #include <gstreamermm/pushsrc.h>
 
+// Base library includes
+#include <gstreamermm/audioclock.h>
+#include <gstreamermm/audiofilter.h>
+#include <gstreamermm/audiosink.h>
+#include <gstreamermm/audiosrc.h>
+#include <gstreamermm/baseaudiosink.h>
+#include <gstreamermm/baseaudiosrc.h>
+#include <gstreamermm/cddabasesrc.h>
+
+// Base inteface includes
+#include <gstreamermm/colorbalance.h>
+#include <gstreamermm/colorbalancechannel.h>
+#include <gstreamermm/mixer.h>
+#include <gstreamermm/mixeroptions.h>
+#include <gstreamermm/mixertrack.h>
+#include <gstreamermm/propertyprobe.h>
+#include <gstreamermm/tuner.h>
+#include <gstreamermm/tunerchannel.h>
+#include <gstreamermm/tunernorm.h>
+#include <gstreamermm/videoorientation.h>
+#include <gstreamermm/xoverlay.h>
+
 #endif // _GSTREAMERMM_H
